@@ -8,25 +8,17 @@
 #' (e.g. this is a useful error message). Learn more in
 #' `vignette("snapshotting")`.
 #'
-#' * `expect_snapshot()` captures all messages, warnings, errors, and
-#'    output from code.
-#' * `expect_snapshot_output()` captures just output printed to the console.
-#' * `expect_snapshot_error()` captures an error message and
-#'   optionally checks its class.
-#' * `expect_snapshot_warning()` captures a warning message and
-#'   optionally checks its class.
-#' * `expect_snapshot_value()` captures the return value.
-#'
-#' (These functions supersede [verify_output()], [expect_known_output()],
-#' [expect_known_value()], and [expect_known_hash()].)
+#' `expect_snapshot()` runs code as if you had executed it at the console, and
+#' records the results, including output, messages, warnings, and errors.
+#' If you just want to compare the result, try [expect_snapshot_value()].
 #'
 #' @section Workflow:
 #' The first time that you run a snapshot expectation it will run `x`,
-#' capture the results, and record in `tests/testthat/snap/{test}.json`.
+#' capture the results, and record them in `tests/testthat/_snaps/{test}.md`.
 #' Each test file gets its own snapshot file, e.g. `test-foo.R` will get
-#' `snap/foo.json`.
+#' `_snaps/foo.md`.
 #'
-#' It's important to review the JSON files and commit them to git. They are
+#' It's important to review the Markdown files and commit them to git. They are
 #' designed to be human readable, and you should always review new additions
 #' to ensure that the salient information has been captured. They should also
 #' be carefully reviewed in pull requests, to make sure that snapshots have
@@ -34,7 +26,7 @@
 #'
 #' On subsequent runs, the result of `x` will be compared to the value stored
 #' on disk. If it's different, the expectation will fail, and a new file
-#' `snap/{test}.new.json` will be created. If the change was deliberate,
+#' `_snaps/{test}.new.md` will be created. If the change was deliberate,
 #' you can approve the change with [snapshot_accept()] and then the tests will
 #' pass the next time you run them.
 #'
@@ -50,13 +42,11 @@
 #' @param error Do you expect the code to throw an error? The expectation
 #'   will fail (even on CRAN) if an unexpected error is thrown or the
 #'   expected error is not thrown.
-#' @param variant `r lifecycle::badge("experimental")`
+#' @param variant If non-`NULL`, results will be saved in
+#'   `_snaps/{variant}/{test.md}`, so `variant` must be a single string
+#'   suitable for use as a directory name.
 #'
-#'   If not-`NULL`, results will be saved in `_snaps/{variant}/{test.md}`,
-#'   so `variant` must be a single string of alphanumeric characters suitable
-#'   for use as a directory name.
-#'
-#'   You can variants to deal with cases where the snapshot output varies
+#'   You can use variants to deal with cases where the snapshot output varies
 #'   and you want to capture and test the variations. Common use cases include
 #'   variations for operating system, R version, or version of key dependency.
 #'   Variants are an advanced feature. When you use them, you'll need to
@@ -167,7 +157,7 @@ snapshot_replay_condition_legacy <- function(x, state = env(), transform = NULL)
   if (inherits(x, "error")) {
     state$error <- x
     type <- "Error"
-    msg <- add_implict_nl(msg)
+    msg <- add_implicit_nl(msg)
   } else if (inherits(x, "warning")) {
     type <- "Warning"
     msg <- paste0(msg, "\n")
@@ -191,7 +181,7 @@ snapshot_lines <- function(x, transform = NULL) {
   x
 }
 
-add_implict_nl <- function(x) {
+add_implicit_nl <- function(x) {
   if (substr(x, nchar(x), nchar(x)) == "\n") {
     x
   } else {
@@ -206,8 +196,24 @@ snap_header <- function(state, header) {
   }
 }
 
+#' Snapshot helpers
+#'
+#' @description
+#' `r lifecycle::badge("questioning")`
+#'
+#' These snapshotting functions are questioning because they were developed
+#' before [expect_snapshot()] and we're not sure that they still have a
+#' role to play.
+#'
+#' * `expect_snapshot_output()` captures just output printed to the console.
+#' * `expect_snapshot_error()` captures an error message and
+#'   optionally checks its class.
+#' * `expect_snapshot_warning()` captures a warning message and
+#'   optionally checks its class.
+#'
+#' @inheritParams expect_snapshot
+#' @keywords internal
 #' @export
-#' @rdname expect_snapshot
 expect_snapshot_output <- function(x, cran = FALSE, variant = NULL) {
   edition_require(3, "expect_snapshot_output()")
   variant <- check_variant(variant)
@@ -228,7 +234,7 @@ expect_snapshot_output <- function(x, cran = FALSE, variant = NULL) {
 #'   always fail (even on CRAN) if an error of this class isn't seen
 #'   when executing `x`.
 #' @export
-#' @rdname expect_snapshot
+#' @rdname expect_snapshot_output
 expect_snapshot_error <- function(x, class = "error", cran = FALSE, variant = NULL) {
   edition_require(3, "expect_snapshot_error()")
   expect_snapshot_condition(
@@ -240,7 +246,7 @@ expect_snapshot_error <- function(x, class = "error", cran = FALSE, variant = NU
 }
 
 #' @export
-#' @rdname expect_snapshot
+#' @rdname expect_snapshot_output
 expect_snapshot_warning <- function(x, class = "warning", cran = FALSE, variant = NULL) {
   edition_require(3, "expect_snapshot_warning()")
   expect_snapshot_condition(
@@ -273,6 +279,12 @@ expect_snapshot_condition <- function(base_class, x, class, cran = FALSE, varian
   )
 }
 
+#' Snapshot testing for values
+#'
+#' Captures the result of function, flexibly serializing it into a text
+#' representation that's stored in a snapshot file. See [expect_snapshot()]
+#' for more details on snapshot testing.
+#'
 #' @param style Serialization style to use:
 #'   * `json` uses [jsonlite::fromJSON()] and [jsonlite::toJSON()]. This
 #'      produces the simplest output but only works for relatively simple
@@ -284,11 +296,11 @@ expect_snapshot_condition <- function(base_class, x, class, cran = FALSE, varian
 #'   * `serialize()` produces a binary serialization of the object using
 #'     [serialize()]. This is all but guaranteed to work for any R object,
 #'     but produces a completely opaque serialization.
-#' @param ... For `expect_snapshot_value()` only, passed on to
-#'   [waldo::compare()] so you can control the details of the comparison.
-#' @export
+#' @param ... Passed on to [waldo::compare()] so you can control the details of
+#'   the comparison.
+#' @inheritParams expect_snapshot
 #' @inheritParams compare
-#' @rdname expect_snapshot
+#' @export
 expect_snapshot_value <- function(x,
                                   style = c("json", "json2", "deparse", "serialize"),
                                   cran = FALSE,
@@ -394,8 +406,10 @@ expect_snapshot_helper <- function(lab, val,
   )
 }
 
-snapshot_accept_hint <- function(variant, file) {
-  local_reporter_output()
+snapshot_accept_hint <- function(variant, file, reset_output = TRUE) {
+  if (reset_output) {
+    local_reporter_output()
+  }
 
   if (is.null(variant) || variant == "_default") {
     name <- file
@@ -403,23 +417,18 @@ snapshot_accept_hint <- function(variant, file) {
     name <- file.path(variant, file)
   }
 
-  code_accept <- paste0("snapshot_accept('", name, "')")
-  code_review <- paste0("snapshot_review('", name, "')")
-  link <- function(code) {
-    cli::style_hyperlink(code, paste0("rstudio:run:testthat::", code))
-  }
   paste0(
-    "* Run `", link(code_accept), "` to accept the change\n",
-    "* Run `", link(code_review), "` to interactively review the change"
+    cli::format_inline("* Run {.run testthat::snapshot_accept('{name}')} to accept the change."), "\n",
+    cli::format_inline("* Run {.run testthat::snapshot_review('{name}')} to interactively review the change.")
   )
 }
 
 snapshot_not_available <- function(message) {
-  inform(c(
-    crayon::bold("Can't compare snapshot to reference when testing interactively"),
-    i = "Run `devtools::test()` or `testthat::test_file()` to see changes",
-    i = message
+  cli::cli_inform(c(
+    "{.strong Can't compare snapshot to reference when testing interactively.}",
+    i = "Run {.run devtools::test()} or {.code testthat::test_file()} to see changes."
   ))
+  cat(message, "\n", sep = "")
 }
 
 local_snapshot_dir <- function(snap_names, .env = parent.frame()) {
