@@ -36,7 +36,7 @@ test_that("failed expect_error() prints a backtrace", {
 })
 
 test_that("Errors are inspected with `conditionMessage()`", {
-  rlang::scoped_bindings(
+  rlang::local_bindings(
     .env = globalenv(),
     conditionMessage.foobar = function(...) "dispatched"
   )
@@ -58,3 +58,13 @@ test_that("deep stacks are trimmed", {
   f(25)
 })
 
+# Expectations ----------------------------------------------------------------
+f <- function() g()
+g <- function() h()
+h <- function() expect_true(FALSE)
+
+f()
+
+test_that("nested expectations get backtraces", {
+  f()
+})
