@@ -23,6 +23,16 @@ test_that("error for non-vectors", {
   expect_error(expect_setequal(sum, sum), "be vectors")
 })
 
+test_that("useful message on faillure", {
+  x1 <- c("a", "b")
+  x2 <- c("b", "c")
+  y1 <- 1:3
+  y2 <- 2:50
+
+  expect_snapshot_failure(expect_setequal(x1, x2))
+  expect_snapshot_failure(expect_setequal(y1, y2))
+})
+
 # mapequal ----------------------------------------------------------------
 
 test_that("ignores order", {
